package Test::Harness::Selenium;
use strictures 1;

use File::Find;
use WWW::Selenium;
use HTML::TableExtract;
use IO::All;

use Test::Builder;
BEGIN {
  package Test::Builder;

  use Class::Method::Modifiers;
  use ExtUtils::MakeMaker qw(prompt);

  if (!$ENV{AUTOMATED_TESTING}) {
    around ok => sub {
      my ($orig, $self) = (shift, shift);
      my $res = $self->$orig(@_);
      unless ($res) {
        if ('y' eq prompt "Well that didn't work, did it. Bail out?", 'y') {
          exit 255;
        }
      }
      return $res;
    };
  }
}

sub test_directory {
  my ($self) = @_;
  my @tests = File::Find::Rule->file()->name('*.html')->in($self->{dir});
  $self->run_tests_for($_) for @tests;
}

sub run_tests_for {
  my ($self, $html_file) = @_;
  my $rows = $self->get_rows_for($html_file);
  my $src = WWW::Selenium->new(
    host => $args->{host},
    port => $args->{port},
    browser_url => $args->{browser_url},
  );
  $src->run_test_table($rows);
}

my $te = HTML::TableExtract->new;
sub get_rows_for {
  my ($self, $html_file) = @_;
  my $html = io($html_file)->all;
  $te->parse($html);
  my $table = ($te->tables)[0];
  my @rows = map {
    [ map { $_ eq "\240" ? () : $_ } @$_ ]
  } $table->rows;
  return \@rows;
}

1;
